

.pricing-table .panel-heading {
    text-align: center;
    text-transform: uppercase;
    font-weight: bold;
}

.pricing-table .panel-body {
    background-color: #3F3F3F;
    color: #fff;
    text-align: center;
}

.pricing-table .panel-body .price {
    font-size: 40px;
    display: inline-block;
}

.pricing-table .price > .dollar-sign {
    vertical-align: super;
    font-size: 16px;
}

.pricing-table .time-period {
    color: #9f9f9f;
    font-size: 15px;
    font-weight: lighter;
}

.pricing-table .list-group {
    padding: 0 15px;
}

.pricing-table .list-group > .list-group-item {
    border-style: dotted;
    text-align: center;
    color: #808080;
}

.pricing-table .list-group-item > .fa {
    font-size: 13px;
    margin-right: 5px;
}

.pricing-table .btn {
    display: block;
    text-transform: uppercase;
    margin: 30px auto 20px;
    padding: 13px 35px 13px 35px;
    border-radius: 4px;
}